==> bitbazaar-0.0.2.tar.gz: bitbazaar-0.0.2/README.md <==
# BitBazaar

[![License](https://img.shields.io/badge/License-MIT-green.svg)][license]
[![Documentation](https://img.shields.io/badge/Documentation-8A2BE2)](https://zakstucke.github.io/bitbazaar)

[license]: https://github.com/zakstucke/bitbazaar/blob/main/LICENSE.md

An assortment of publicly available cross-language utilities useful to my projects.

### Python

[![PyPI](https://img.shields.io/pypi/v/bitbazaar.svg)][pypi status]
[![Status](https://img.shields.io/pypi/status/bitbazaar.svg)][pypi status]
[![Python Version](https://img.shields.io/pypi/pyversions/bitbazaar)][pypi status]
![Coverage](https://img.shields.io/badge/Coverage-100%25-green)

[pypi status]: https://pypi.org/project/bitbazaar/

You can install **BitBazaar** via [pip](https://pip.pypa.io/) from [PyPI](https://pypi.org/):

```console
pip install bitbazaar
```

### Javascript

[![npm version](https://img.shields.io/npm/v/bitbazaar.svg?style=flat)](https://www.npmjs.com/package/bitbazaar)
![Coverage](https://img.shields.io/badge/Coverage-100%25-green)

You can install **BitBazaar** via [npm](https://www.npmjs.com/):

```console
npm install bitbazaar
```

### Rust-backed Python library

[![PyPI](https://img.shields.io/pypi/v/bitbazaar_rs.svg)][pypi status]
[![Status](https://img.shields.io/pypi/status/bitbazaar_rs.svg)][pypi status]
[![Python Version](https://img.shields.io/pypi/pyversions/bitbazaar_rs)][pypi status]

[pypi status]: https://pypi.org/project/bitbazaar_rs/

You can install **BitBazaar** via [pip](https://pip.pypa.io/) from [PyPI](https://pypi.org/):

```console
pip install bitbazaar_rs
```

Binaries are available for:

-   **Linux**: `x86_64`, `aarch64`, `i686`, `armv7l`, `musl-x86_64` & `musl-aarch64`
-   **MacOS**: `x86_64` & `arm64`
-   **Windows**: `amd64` & `win32`

### Rust

[![Crates.io](https://img.shields.io/crates/v/bitbazaar.svg)](https://crates.io/crates/bitbazaar)

You can install **BitBazaar** via [crates.io](https://crates.io/):

```yaml
# Cargo.toml

[dependencies]
bitbazaar = "0.0.21"
```

## Usage

Please see the [documentation](https://zakstucke.github.io/bitbazaar) for details.

## Contributing

Contributions are very welcome.
To learn more, see the [Contributor Guide](CONTRIBUTING.md).

## License

Distributed under the terms of the [MIT license](LICENSE.md),
**BitBazaar** is free and open source software.

## Issues

If you encounter any problems,
please [file an issue](https://github.com/zakstucke/bitbazaar/issues) along with a detailed description.

==> bitbazaar-0.0.4.tar.gz: bitbazaar-0.0.4/README.md <==

# BitBazaar

[![License](https://img.shields.io/badge/License-MIT-green.svg)][license]
[![Documentation](https://img.shields.io/badge/Documentation-8A2BE2)](https://zakstucke.github.io/bitbazaar)

[license]: https://github.com/zakstucke/bitbazaar/blob/main/LICENSE.md

An assortment of publicly available cross-language utilities useful to my projects.

### Python



[![PyPI](https://img.shields.io/pypi/v/bitbazaar.svg)][pypi status]
[![Status](https://img.shields.io/pypi/status/bitbazaar.svg)][pypi status]
[![Python Version](https://img.shields.io/pypi/pyversions/bitbazaar)][pypi status]
![Coverage](https://img.shields.io/badge/Coverage-100%25-green)

[pypi status]: https://pypi.org/project/bitbazaar/

You can install **BitBazaar** via [pip](https://pip.pypa.io/) from [PyPI](https://pypi.org/):

```console
pip install bitbazaar
```


### Javascript



[![npm version](https://img.shields.io/npm/v/bitbazaar.svg?style=flat)](https://www.npmjs.com/package/bitbazaar)
![Coverage](https://img.shields.io/badge/Coverage-100%25-green)

You can install **BitBazaar** via [npm](https://www.npmjs.com/):

```console
npm install bitbazaar
```


### Rust-backed Python library



[![PyPI](https://img.shields.io/pypi/v/bitbazaar_rs.svg)][pypi status]
[![Status](https://img.shields.io/pypi/status/bitbazaar_rs.svg)][pypi status]
[![Python Version](https://img.shields.io/pypi/pyversions/bitbazaar_rs)][pypi status]

[pypi status]: https://pypi.org/project/bitbazaar_rs/

You can install **BitBazaar** via [pip](https://pip.pypa.io/) from [PyPI](https://pypi.org/):

```console
pip install bitbazaar_rs
```

Binaries are available for:

* **Linux**: `x86_64`, `aarch64`, `i686`, `armv7`, `ppc64le`, `s390x`,  `musl-x86_64` & `musl-aarch64`
* **MacOS**: `x86_64`, `aarch64`
* **Windows**: `x86_64`, `aarch64`, `i686`

If your platform isn't supported, [file an issue](https://github.com/zakstucke/bitbazaar/issues).


### Rust



[![Crates.io](https://img.shields.io/crates/v/bitbazaar.svg)](https://crates.io/crates/bitbazaar)

You can install **BitBazaar** via [crates.io](https://crates.io/):

```yaml
# Cargo.toml

[dependencies]
bitbazaar = "0.0.28"
```


## Usage

Please see the [documentation](https://zakstucke.github.io/bitbazaar) for details.

## Contributing

Contributions are very welcome.
To learn more, see the [Contributor Guide](CONTRIBUTING.md).

## License

Distributed under the terms of the [MIT license](LICENSE.md),
**BitBazaar** is free and open source software.

## Issues

If you encounter any problems,
please [file an issue](https://github.com/zakstucke/bitbazaar/issues) along with a detailed description.
